summaryrefslogtreecommitdiff
path: root/chromium/components/variations/variations_seed_processor.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/variations/variations_seed_processor.cc')
-rw-r--r--chromium/components/variations/variations_seed_processor.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/components/variations/variations_seed_processor.cc b/chromium/components/variations/variations_seed_processor.cc
index 3bc232fdbdc..58e41585210 100644
--- a/chromium/components/variations/variations_seed_processor.cc
+++ b/chromium/components/variations/variations_seed_processor.cc
@@ -84,12 +84,12 @@ void ForceExperimentState(
base::FieldTrial* trial) {
RegisterExperimentParams(study, experiment);
RegisterVariationIds(experiment, study.name());
- if (study.activation_type() == Study_ActivationType_ACTIVATION_AUTO) {
+ if (study.activation_type() == Study_ActivationType_ACTIVATE_ON_STARTUP) {
// This call must happen after all params have been registered for the
// trial. Otherwise, since we look up params by trial and group name, the
// params won't be registered under the correct key.
trial->group();
// UI Strings can only be overridden from ACTIVATION_AUTO experiments.
ApplyUIStringOverrides(experiment, override_callback);
}
}
@@ -297,7 +297,7 @@ void VariationsSeedProcessor::CreateTrialFromStudy(
if (enables_or_disables_features)
RegisterFeatureOverrides(processed_study, trial.get(), feature_list);
- if (study.activation_type() == Study_ActivationType_ACTIVATION_AUTO) {
+ if (study.activation_type() == Study_ActivationType_ACTIVATE_ON_STARTUP) {
// This call must happen after all params have been registered for the
// trial. Otherwise, since we look up params by trial and group name, the
// params won't be registered under the correct key.
@@ -308,7 +308,7 @@ void VariationsSeedProcessor::CreateTrialFromStudy(
if (!has_overrides)
return;
// UI Strings can only be overridden from ACTIVATION_AUTO experiments.
int experiment_index = processed_study.GetExperimentIndexByName(group_name);
// If the chosen experiment was not found in the study, simply return.
// Although not normally expected, but could happen in exception cases, see
@@ -84,12 +84,12 @@ void ForceExperimentState(
// params won't be registered under the correct key.
trial->group();
- // UI Strings can only be overridden from ACTIVATION_AUTO experiments.
+ // UI Strings can only be overridden from ACTIVATE_ON_STARTUP experiments.
ApplyUIStringOverrides(experiment, override_callback);
}
@@ -308,7 +308,7 @@ void VariationsSeedProcessor::CreateTrialFromStudy(
if (!has_overrides)
return;
- // UI Strings can only be overridden from ACTIVATION_AUTO experiments.
+ // UI Strings can only be overridden from ACTIVATE_ON_STARTUP experiments.
int experiment_index = processed_study.GetExperimentIndexByName(group_name);
// If the chosen experiment was not found in the study, simply return.